pub struct HttpBatchTransport { /* private fields */ }Expand description
HTTP Batch transport collects messages and sends them as a single HTTP request
Implementations
Sourceimpl HttpBatchTransport
impl HttpBatchTransport
pub fn new(endpoint: String) -> Self
Sourcepub async fn execute(&mut self) -> Result<(), TransportError>
pub async fn execute(&mut self) -> Result<(), TransportError>
Execute the batch - send all queued messages and receive responses This is a placeholder implementation that will need an actual HTTP client
pub fn endpoint(&self) -> &str
pub fn pending_outgoing(&self) -> usize
pub fn pending_incoming(&self) -> usize